import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { ErrorT, ProductForViewT, ProductForCheckoutT, RecommendationT, RecommenderT, ZoneResponseT, RecommendersResponseT, ActivityResponseT, RecommendationsResponseT } from "./einsteinQuickStartGuide.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class EinsteinQuickStartGuide extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Tells the Einstein engine when a user views a product.
    *
    * If you would like to get a raw Response object use the other sendViewProduct function.
    *
    * @returns A promise of type ActivityResponseT
    */
    sendViewProduct(options: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<ActivityResponseT>;
    /**
    * Tells the Einstein engine when a user views a product.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ActivityResponseT otherwise
    */
    sendViewProduct<T extends boolean>(options: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }, rawResponse?: T): Promise<T extends true ? Response : ActivityResponseT>;
    /**
    * Tells the Einstein engine when a user views a set of recommendations
    *
    * If you would like to get a raw Response object use the other sendViewReco function.
    *
    * @returns A promise of type ActivityResponseT
    */
    sendViewReco(options: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<ActivityResponseT>;
    /**
    * Tells the Einstein engine when a user views a set of recommendations
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ActivityResponseT otherwise
    */
    sendViewReco<T extends boolean>(options: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }, rawResponse?: T): Promise<T extends true ? Response : ActivityResponseT>;
    /**
    * Tells the Einstein engine when a user clicks on a recommendation
    *
    * If you would like to get a raw Response object use the other sendClickReco function.
    *
    * @returns A promise of type ActivityResponseT
    */
    sendClickReco(options: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<ActivityResponseT>;
    /**
    * Tells the Einstein engine when a user clicks on a recommendation
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ActivityResponseT otherwise
    */
    sendClickReco<T extends boolean>(options: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }, rawResponse?: T): Promise<T extends true ? Response : ActivityResponseT>;
    /**
    * Tells the Einstein engine when a user adds an item to their cart.
    *
    * If you would like to get a raw Response object use the other sendAddToCart function.
    *
    * @returns A promise of type ActivityResponseT
    */
    sendAddToCart(options: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<ActivityResponseT>;
    /**
    * Tells the Einstein engine when a user adds an item to their cart.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ActivityResponseT otherwise
    */
    sendAddToCart<T extends boolean>(options: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }, rawResponse?: T): Promise<T extends true ? Response : ActivityResponseT>;
    /**
    * Get a list of recommenders that can be used in recommendation requests.
    *
    * If you would like to get a raw Response object use the other getRecommenders function.
    *
    * @returns A promise of type RecommendersResponseT
    */
    getRecommenders(options?: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<RecommendersResponseT>;
    /**
    * Get a list of recommenders that can be used in recommendation requests.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type RecommendersResponseT otherwise
    */
    getRecommenders<T extends boolean>(options?: {
        parameters?: {
            siteId: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : RecommendersResponseT>;
    /**
    * Get a set of recommendations
    *
    * If you would like to get a raw Response object use the other getRecommendations function.
    *
    * @returns A promise of type RecommendationsResponseT
    */
    getRecommendations(options: {
        parameters?: {
            siteId: string;
            recommenderName: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<RecommendationsResponseT>;
    /**
    * Get a set of recommendations
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type RecommendationsResponseT otherwise
    */
    getRecommendations<T extends boolean>(options: {
        parameters?: {
            siteId: string;
            recommenderName: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }, rawResponse?: T): Promise<T extends true ? Response : RecommendationsResponseT>;
    /**
    * Get a set of recommendations for a zone
    *
    * If you would like to get a raw Response object use the other getZoneRecommendations function.
    *
    * @returns A promise of type ZoneResponseT
    */
    getZoneRecommendations(options: {
        parameters?: {
            siteId: string;
            zoneName: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<ZoneResponseT>;
    /**
    * Get a set of recommendations for a zone
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ZoneResponseT otherwise
    */
    getZoneRecommendations<T extends boolean>(options: {
        parameters?: {
            siteId: string;
            zoneName: string;
            clientId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }, rawResponse?: T): Promise<T extends true ? Response : ZoneResponseT>;
}
declare module EinsteinQuickStartGuide {
    type Error = ErrorT;
    type ProductForView = ProductForViewT;
    type ProductForCheckout = ProductForCheckoutT;
    type Recommendation = RecommendationT;
    type Recommender = RecommenderT;
    type ZoneResponse = ZoneResponseT;
    type RecommendersResponse = RecommendersResponseT;
    type ActivityResponse = ActivityResponseT;
    type RecommendationsResponse = RecommendationsResponseT;
}
export = EinsteinQuickStartGuide;
