import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { MoneyT, SimpleSearchResultT, SearchRequestT, PaginatedSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT, CustomPropertiesT, PaymentTransactionUpdateRequestT, PaymentInstrumentUpdateRequestT, OrderPaymentStatusUpdateRequestT, OrderConfirmationStatusUpdateRequestT, ShippingAddressUpdateRequestT, OrderExternalStatusUpdateRequestT, OrderShippingStatusUpdateRequestT, OrderUpdateRequestT, OrderExportStatusUpdateRequestT, OrderStatusUpdateRequestT } from "./orders.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class Orders extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Updates the order.
    *
    * If you would like to get a raw Response object use the other updateOrder function.
    *
    * @returns A promise of type void
    */
    updateOrder(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates the order.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrder<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order confirmation status.
    *
    * If you would like to get a raw Response object use the other updateOrderConfirmationStatus function.
    *
    * @returns A promise of type void
    */
    updateOrderConfirmationStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderConfirmationStatusUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates the order confirmation status.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrderConfirmationStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderConfirmationStatusUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order export status. Setting the status to EXPORTED will also trigger the finalization of on-order inventory transactions for this order, meaning that all inventory transactions with type on-order are moved into final inventory transactions. This is only relevant when on-order inventory is turned on for the inventory list ordered products are in.
    *
    * If you would like to get a raw Response object use the other updateOrderExportStatus function.
    *
    * @returns A promise of type void
    */
    updateOrderExportStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderExportStatusUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates the order export status. Setting the status to EXPORTED will also trigger the finalization of on-order inventory transactions for this order, meaning that all inventory transactions with type on-order are moved into final inventory transactions. This is only relevant when on-order inventory is turned on for the inventory list ordered products are in.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrderExportStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderExportStatusUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order external status.
    *
    * If you would like to get a raw Response object use the other updateOrderExternalStatus function.
    *
    * @returns A promise of type void
    */
    updateOrderExternalStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderExternalStatusUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates the order external status.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrderExternalStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderExternalStatusUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order payment status.
    *
    * If you would like to get a raw Response object use the other updateOrderPaymentStatus function.
    *
    * @returns A promise of type void
    */
    updateOrderPaymentStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderPaymentStatusUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates the order payment status.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrderPaymentStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderPaymentStatusUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order shipping status.
    *
    * If you would like to get a raw Response object use the other updateOrderShippingStatus function.
    *
    * @returns A promise of type void
    */
    updateOrderShippingStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderShippingStatusUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates the order shipping status.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrderShippingStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderShippingStatusUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the order status. Orders which are in status NEW, COMPLETED, or CANCELLED can not be set to status CREATED or FAILED.
    *
    * If you would like to get a raw Response object use the other updateOrderStatus function.
    *
    * @returns A promise of type void
    */
    updateOrderStatus(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderStatusUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates the order status. Orders which are in status NEW, COMPLETED, or CANCELLED can not be set to status CREATED or FAILED.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrderStatus<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderStatusUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the payment instrument of an order.
    *
    * If you would like to get a raw Response object use the other updateOrderPaymentInstrument function.
    *
    * @returns A promise of type void
    */
    updateOrderPaymentInstrument(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: PaymentInstrumentUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates the payment instrument of an order.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrderPaymentInstrument<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: PaymentInstrumentUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the transaction of an order payment instrument.
    *
    * If you would like to get a raw Response object use the other updateOrderPaymentTransaction function.
    *
    * @returns A promise of type void
    */
    updateOrderPaymentTransaction(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: PaymentTransactionUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates the transaction of an order payment instrument.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrderPaymentTransaction<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: PaymentTransactionUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates (create or replace) the order shipment address.
    *
    * If you would like to get a raw Response object use the other updateOrderShippingAddress function.
    *
    * @returns A promise of type void
    */
    updateOrderShippingAddress(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            shipmentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: ShippingAddressUpdateRequestT;
    }): Promise<void>;
    /**
    * Updates (create or replace) the order shipment address.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    updateOrderShippingAddress<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            shipmentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: ShippingAddressUpdateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
}
declare module Orders {
    type Money = MoneyT;
    type SimpleSearchResult = SimpleSearchResultT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
    type CustomProperties = CustomPropertiesT;
    type PaymentTransactionUpdateRequest = PaymentTransactionUpdateRequestT;
    type PaymentInstrumentUpdateRequest = PaymentInstrumentUpdateRequestT;
    type OrderPaymentStatusUpdateRequest = OrderPaymentStatusUpdateRequestT;
    type OrderConfirmationStatusUpdateRequest = OrderConfirmationStatusUpdateRequestT;
    type ShippingAddressUpdateRequest = ShippingAddressUpdateRequestT;
    type OrderExternalStatusUpdateRequest = OrderExternalStatusUpdateRequestT;
    type OrderShippingStatusUpdateRequest = OrderShippingStatusUpdateRequestT;
    type OrderUpdateRequest = OrderUpdateRequestT;
    type OrderExportStatusUpdateRequest = OrderExportStatusUpdateRequestT;
    type OrderStatusUpdateRequest = OrderStatusUpdateRequestT;
}
export = Orders;
