import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { ErrorResponseT, CustomPropertiesT, PaymentCardSpecT, OrderAddressT, BasketsResultT, PaymentCardT, NotesResultT, ShippingItemT, DiscountT, NoteT, CouponItemT, PromotionLinkT, ShippingPromotionT, ProductItemT, BasketPaymentInstrumentRequestT, OrderPaymentInstrumentT, BonusDiscountLineItemT, PaymentMethodResultT, ShipmentT, CustomerInfoT, SimpleLinkT, PriceAdjustmentT, ShippingMethodResultT, ProductDetailsLinkT, OptionItemT, ShippingMethodT, BasketT, OrderPaymentInstrumentRequestT, GiftCertificateItemT, ProductListLinkT, OrderT, OrderPaymentCardRequestT, PaymentMethodT, StatusT, ProductListItemReferenceT, MoneyT, SimpleSearchResultT, SearchRequestT, PaginatedSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT } from "./shopperOrders.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class ShopperOrders extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Submits an order based on a prepared basket. The only considered value from the request body is basketId.
    *
    * If you would like to get a raw Response object use the other createOrder function.
    *
    * @returns A promise of type OrderT
    */
    createOrder(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: BasketT;
    }): Promise<OrderT>;
    /**
    * Submits an order based on a prepared basket. The only considered value from the request body is basketId.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type OrderT otherwise
    */
    createOrder<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: BasketT;
    }, rawResponse?: T): Promise<T extends true ? Response : OrderT>;
    /**
    * Gets information for an order.
    *
    * If you would like to get a raw Response object use the other getOrder function.
    *
    * @returns A promise of type OrderT
    */
    getOrder(options?: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<OrderT>;
    /**
    * Gets information for an order.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type OrderT otherwise
    */
    getOrder<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : OrderT>;
    /**
    * Adds a payment instrument to an order.

Details:

The payment instrument is added with the provided details. The payment method must be applicable for the order see GET
/baskets/{basketId}/payment-methods, if the payment method is &#x27;CREDIT_CARD&#x27; a paymentCard must be specified in the request.
    *
    * If you would like to get a raw Response object use the other createPaymentInstrumentForOrder function.
    *
    * @returns A promise of type OrderT
    */
    createPaymentInstrumentForOrder(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderPaymentInstrumentRequestT;
    }): Promise<OrderT>;
    /**
    * Adds a payment instrument to an order.

Details:

The payment instrument is added with the provided details. The payment method must be applicable for the order see GET
/baskets/{basketId}/payment-methods, if the payment method is &#x27;CREDIT_CARD&#x27; a paymentCard must be specified in the request.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type OrderT otherwise
    */
    createPaymentInstrumentForOrder<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderPaymentInstrumentRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : OrderT>;
    /**
    * Removes a payment instrument of an order.
    *
    * If you would like to get a raw Response object use the other removePaymentInstrumentFromOrder function.
    *
    * @returns A promise of type OrderT
    */
    removePaymentInstrumentFromOrder(options?: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<OrderT>;
    /**
    * Removes a payment instrument of an order.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type OrderT otherwise
    */
    removePaymentInstrumentFromOrder<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : OrderT>;
    /**
    * Updates a payment instrument of an order.

Details:

The payment instrument is updated with the provided details. The payment method must be applicable for the
order see GET /baskets/{basketId}/payment-methods, if the payment method is &#x27;CREDIT_CARD&#x27; a
paymentCard must be specified in the request.
    *
    * If you would like to get a raw Response object use the other updatePaymentInstrumentForOrder function.
    *
    * @returns A promise of type OrderT
    */
    updatePaymentInstrumentForOrder(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderPaymentInstrumentRequestT;
    }): Promise<OrderT>;
    /**
    * Updates a payment instrument of an order.

Details:

The payment instrument is updated with the provided details. The payment method must be applicable for the
order see GET /baskets/{basketId}/payment-methods, if the payment method is &#x27;CREDIT_CARD&#x27; a
paymentCard must be specified in the request.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type OrderT otherwise
    */
    updatePaymentInstrumentForOrder<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            paymentInstrumentId: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: OrderPaymentInstrumentRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : OrderT>;
    /**
    * Gets the applicable payment methods for an existing order considering the open payment amount only.
    *
    * If you would like to get a raw Response object use the other getPaymentMethodsForOrder function.
    *
    * @returns A promise of type PaymentMethodResultT
    */
    getPaymentMethodsForOrder(options?: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<PaymentMethodResultT>;
    /**
    * Gets the applicable payment methods for an existing order considering the open payment amount only.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type PaymentMethodResultT otherwise
    */
    getPaymentMethodsForOrder<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            orderNo: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : PaymentMethodResultT>;
}
declare module ShopperOrders {
    type ErrorResponse = ErrorResponseT;
    type CustomProperties = CustomPropertiesT;
    type PaymentCardSpec = PaymentCardSpecT;
    type OrderAddress = OrderAddressT;
    type BasketsResult = BasketsResultT;
    type PaymentCard = PaymentCardT;
    type NotesResult = NotesResultT;
    type ShippingItem = ShippingItemT;
    type Discount = DiscountT;
    type Note = NoteT;
    type CouponItem = CouponItemT;
    type PromotionLink = PromotionLinkT;
    type ShippingPromotion = ShippingPromotionT;
    type ProductItem = ProductItemT;
    type BasketPaymentInstrumentRequest = BasketPaymentInstrumentRequestT;
    type OrderPaymentInstrument = OrderPaymentInstrumentT;
    type BonusDiscountLineItem = BonusDiscountLineItemT;
    type PaymentMethodResult = PaymentMethodResultT;
    type Shipment = ShipmentT;
    type CustomerInfo = CustomerInfoT;
    type SimpleLink = SimpleLinkT;
    type PriceAdjustment = PriceAdjustmentT;
    type ShippingMethodResult = ShippingMethodResultT;
    type ProductDetailsLink = ProductDetailsLinkT;
    type OptionItem = OptionItemT;
    type ShippingMethod = ShippingMethodT;
    type Basket = BasketT;
    type OrderPaymentInstrumentRequest = OrderPaymentInstrumentRequestT;
    type GiftCertificateItem = GiftCertificateItemT;
    type ProductListLink = ProductListLinkT;
    type Order = OrderT;
    type OrderPaymentCardRequest = OrderPaymentCardRequestT;
    type PaymentMethod = PaymentMethodT;
    type Status = StatusT;
    type ProductListItemReference = ProductListItemReferenceT;
    type Money = MoneyT;
    type SimpleSearchResult = SimpleSearchResultT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
}
export = ShopperOrders;
