import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { CustomerAddressT, CustomerGroupSearchResultT, CustomerListT, CustomerSearchHitT, CustomerGroupMembersT, RuleT, CustomerGroupT, CustomerGroupMemberSearchResultT, CustomerAddressResultT, CustomerT, CustomerGroupMemberT, CredentialsT, CustomerSearchResultT, SearchRequestT, PaginatedSearchResultT, SimpleSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT, ErrorT, ErrorResponseT } from "./customers.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class Customers extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Action to search for customers in a customer list.
The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:
  
customer_no - String
first_name - String
second_name - String
last_name - String
suffix - String
salutation - String
title - String
fax - String
phone_home - String
phone_business - String
phone_mobile - String
email - String
gender - Integer
company_name - String
credentials.login - String
credentials.enabled - boolean
  
    *
    * If you would like to get a raw Response object use the other searchCustomerInCustomerList function.
    *
    * @returns A promise of type CustomerSearchResultT
    */
    searchCustomerInCustomerList(options: {
        parameters?: {
            organizationId?: string;
            customerListId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }): Promise<CustomerSearchResultT>;
    /**
    * Action to search for customers in a customer list.
The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:
  
customer_no - String
first_name - String
second_name - String
last_name - String
suffix - String
salutation - String
title - String
fax - String
phone_home - String
phone_business - String
phone_mobile - String
email - String
gender - Integer
company_name - String
credentials.login - String
credentials.enabled - boolean
  
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerSearchResultT otherwise
    */
    searchCustomerInCustomerList<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            customerListId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerSearchResultT>;
    /**
    * Action to create a new customer. The customer is created using the specified credentials and customer
information. This action verifies the following:

Login acceptance criteria and uniqueness.
Mandatory customer properties.

If the action fails to create the customer, it returns a 400 fault with an appropriate message.
    *
    * If you would like to get a raw Response object use the other createCustomerList function.
    *
    * @returns A promise of type CustomerT
    */
    createCustomerList(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerT;
    }): Promise<CustomerT>;
    /**
    * Action to create a new customer. The customer is created using the specified credentials and customer
information. This action verifies the following:

Login acceptance criteria and uniqueness.
Mandatory customer properties.

If the action fails to create the customer, it returns a 400 fault with an appropriate message.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerT otherwise
    */
    createCustomerList<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerT>;
    /**
    * Deletes the customer, including all related information like the customer addresses.
    *
    * If you would like to get a raw Response object use the other deleteCustomerFromCustomerList function.
    *
    * @returns A promise of type void
    */
    deleteCustomerFromCustomerList(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<void>;
    /**
    * Deletes the customer, including all related information like the customer addresses.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    deleteCustomerFromCustomerList<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Action to get customer information.
    *
    * If you would like to get a raw Response object use the other getCustomerFromCustomerList function.
    *
    * @returns A promise of type CustomerT
    */
    getCustomerFromCustomerList(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CustomerT>;
    /**
    * Action to get customer information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerT otherwise
    */
    getCustomerFromCustomerList<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerT>;
    /**
    * Updates the customer with the specified information. The customer number is allowed to be updated but results in a
CustomerNumberAlreadyInUseException if there is another customer with the same customer number existing.
    *
    * If you would like to get a raw Response object use the other updateCustomerInCustomerList function.
    *
    * @returns A promise of type CustomerT
    */
    updateCustomerInCustomerList(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerT;
    }): Promise<CustomerT>;
    /**
    * Updates the customer with the specified information. The customer number is allowed to be updated but results in a
CustomerNumberAlreadyInUseException if there is another customer with the same customer number existing.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerT otherwise
    */
    updateCustomerInCustomerList<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerT>;
    /**
    * Action to create a new customer. The customer is created using the specified customer number, credentials, and
customer information. This action verifies the following:

Login acceptance criteria and uniqueness.
Mandatory customer properties.

If the action fails to create the customer, it returns a 400 fault with an appropriate message.
    *
    * If you would like to get a raw Response object use the other createCustomerInCustomerList function.
    *
    * @returns A promise of type CustomerT | CustomerT
    */
    createCustomerInCustomerList(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerT;
    }): Promise<CustomerT | CustomerT>;
    /**
    * Action to create a new customer. The customer is created using the specified customer number, credentials, and
customer information. This action verifies the following:

Login acceptance criteria and uniqueness.
Mandatory customer properties.

If the action fails to create the customer, it returns a 400 fault with an appropriate message.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerT | CustomerT otherwise
    */
    createCustomerInCustomerList<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerT | CustomerT>;
    /**
    * Action that returns a pageable list of all customer addresses. The
default page size is 10 customer addresses.
    *
    * If you would like to get a raw Response object use the other getAddressesForCustomerFromCustomerList function.
    *
    * @returns A promise of type CustomerAddressResultT
    */
    getAddressesForCustomerFromCustomerList(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CustomerAddressResultT>;
    /**
    * Action that returns a pageable list of all customer addresses. The
default page size is 10 customer addresses.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerAddressResultT otherwise
    */
    getAddressesForCustomerFromCustomerList<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerAddressResultT>;
    /**
    * The action creates a new customer address with the given address
information.
    *
    * If you would like to get a raw Response object use the other CreateAddressForCustomerInCustomerList function.
    *
    * @returns A promise of type CustomerAddressT
    */
    CreateAddressForCustomerInCustomerList(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerAddressT;
    }): Promise<CustomerAddressT>;
    /**
    * The action creates a new customer address with the given address
information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerAddressT otherwise
    */
    CreateAddressForCustomerInCustomerList<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerAddressT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerAddressT>;
    /**
    * Action that returns a single customer address from a customer list.
    *
    * If you would like to get a raw Response object use the other getAddressForCustomerFromCustomerList function.
    *
    * @returns A promise of type CustomerAddressT
    */
    getAddressForCustomerFromCustomerList(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
            addressId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CustomerAddressT>;
    /**
    * Action that returns a single customer address from a customer list.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerAddressT otherwise
    */
    getAddressForCustomerFromCustomerList<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
            addressId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerAddressT>;
    /**
    * Action which deletes a customer address.
    *
    * If you would like to get a raw Response object use the other removeAddressForCustomerInCustomerList function.
    *
    * @returns A promise of type void
    */
    removeAddressForCustomerInCustomerList(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
            addressId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<void>;
    /**
    * Action which deletes a customer address.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    removeAddressForCustomerInCustomerList<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
            addressId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Action which updates an address of a customer with the given address information.
    *
    * If you would like to get a raw Response object use the other updateAddressForCustomerInCustomerList function.
    *
    * @returns A promise of type CustomerAddressT
    */
    updateAddressForCustomerInCustomerList(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
            addressId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerAddressT;
    }): Promise<CustomerAddressT>;
    /**
    * Action which updates an address of a customer with the given address information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerAddressT otherwise
    */
    updateAddressForCustomerInCustomerList<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            listId: string;
            customerNo: string;
            addressId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerAddressT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerAddressT>;
    /**
    * Action to get site customer groups.
    *
    * If you would like to get a raw Response object use the other getAllCustomerGroupsFromSite function.
    *
    * @returns A promise of type CustomerGroupT
    */
    getAllCustomerGroupsFromSite(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CustomerGroupT>;
    /**
    * Action to get site customer groups.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerGroupT otherwise
    */
    getAllCustomerGroupsFromSite<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerGroupT>;
    /**
    * Action to get customer group information.
    *
    * If you would like to get a raw Response object use the other getCustomerGroupFromSite function.
    *
    * @returns A promise of type CustomerGroupT
    */
    getCustomerGroupFromSite(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CustomerGroupT>;
    /**
    * Action to get customer group information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerGroupT otherwise
    */
    getCustomerGroupFromSite<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerGroupT>;
    /**
    * Triggers customer group deletion by ID. The deletion happens via asynchronous batch process
which is the reason the deletion itself is not necessarily finished after the call to this resource is returned. The customer group that is in deletion is provided in the response.
    *
    * If you would like to get a raw Response object use the other deleteCustomerGroupFromSite function.
    *
    * @returns A promise of type void
    */
    deleteCustomerGroupFromSite(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<void>;
    /**
    * Triggers customer group deletion by ID. The deletion happens via asynchronous batch process
which is the reason the deletion itself is not necessarily finished after the call to this resource is returned. The customer group that is in deletion is provided in the response.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    deleteCustomerGroupFromSite<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Updates the customer group with the specified information.
    *
    * If you would like to get a raw Response object use the other updateCustomerGroupInSite function.
    *
    * @returns A promise of type CustomerGroupT
    */
    updateCustomerGroupInSite(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerGroupT;
    }): Promise<CustomerGroupT>;
    /**
    * Updates the customer group with the specified information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerGroupT otherwise
    */
    updateCustomerGroupInSite<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerGroupT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerGroupT>;
    /**
    * Creates a customer group using the information provided.
    *
    * If you would like to get a raw Response object use the other createCustomerGroupInSite function.
    *
    * @returns A promise of type CustomerGroupT | CustomerGroupT
    */
    createCustomerGroupInSite(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerGroupT;
    }): Promise<CustomerGroupT | CustomerGroupT>;
    /**
    * Creates a customer group using the information provided.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerGroupT | CustomerGroupT otherwise
    */
    createCustomerGroupInSite<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CustomerGroupT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerGroupT | CustomerGroupT>;
    /**
    * Searches for customer group members. For dynamic customer groups, and the system groups &quot;Everyone&quot; and &quot;Unregistered&quot;, no result is returned (Status Code: 204 - No Content).

The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped
into different buckets. These are the searchable attributes with their corresponding buckets:

Main:

      login - String
      active - Boolean

Customer Profile:

      customer_no - String
      first_name - String
      last_name - String
      email - String
      zip - String


Only attributes in the same bucket can be joined using a disjunction (OR).
For instance, when joining login and customer_no above, only a conjunction is allowed (AND), whereas customer_no
and email can be joined using a disjunction because they are in the same bucket.  If an attribute
is used in a disjunction (OR) that violates this rule, an exception is thrown.

The output of the query can also be sorted. These are the list of sortable attributes:

customer_no - String
login - String


If the Business Manager customer search is configured to use the new Search Service, the following differences apply:

    all attributes can be used for sorting (except for &#x27;active&#x27;).
    searching for &#x27;zip&#x27; will only search in the customers default address.
    logical operators can be used without limits (but may result in degraded performance, depending on how they are combined).
    new assignments might not be found immediately via the search service, and removed assignments
    might also not be in effect immediately (there is a slight delay in updating the index).
    *
    * If you would like to get a raw Response object use the other searchMembersInCustomerGroupAssignedToSite function.
    *
    * @returns A promise of type CustomerGroupMemberSearchResultT
    */
    searchMembersInCustomerGroupAssignedToSite(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }): Promise<CustomerGroupMemberSearchResultT>;
    /**
    * Searches for customer group members. For dynamic customer groups, and the system groups &quot;Everyone&quot; and &quot;Unregistered&quot;, no result is returned (Status Code: 204 - No Content).

The query attribute specifies a complex query that can be used to narrow down the search. Attributes are grouped
into different buckets. These are the searchable attributes with their corresponding buckets:

Main:

      login - String
      active - Boolean

Customer Profile:

      customer_no - String
      first_name - String
      last_name - String
      email - String
      zip - String


Only attributes in the same bucket can be joined using a disjunction (OR).
For instance, when joining login and customer_no above, only a conjunction is allowed (AND), whereas customer_no
and email can be joined using a disjunction because they are in the same bucket.  If an attribute
is used in a disjunction (OR) that violates this rule, an exception is thrown.

The output of the query can also be sorted. These are the list of sortable attributes:

customer_no - String
login - String


If the Business Manager customer search is configured to use the new Search Service, the following differences apply:

    all attributes can be used for sorting (except for &#x27;active&#x27;).
    searching for &#x27;zip&#x27; will only search in the customers default address.
    logical operators can be used without limits (but may result in degraded performance, depending on how they are combined).
    new assignments might not be found immediately via the search service, and removed assignments
    might also not be in effect immediately (there is a slight delay in updating the index).
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerGroupMemberSearchResultT otherwise
    */
    searchMembersInCustomerGroupAssignedToSite<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerGroupMemberSearchResultT>;
    /**
    * Action to get all the customer group members with no filtering. For dynamic customer groups, and the system groups &quot;Everyone&quot; and &quot;Unregistered&quot;, no result is returned (Status Code: 204 - No Content).
    *
    * If you would like to get a raw Response object use the other getMembersFromCustomerGroupAssignedToSite function.
    *
    * @returns A promise of type CustomerGroupMembersT
    */
    getMembersFromCustomerGroupAssignedToSite(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CustomerGroupMembersT>;
    /**
    * Action to get all the customer group members with no filtering. For dynamic customer groups, and the system groups &quot;Everyone&quot; and &quot;Unregistered&quot;, no result is returned (Status Code: 204 - No Content).
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerGroupMembersT otherwise
    */
    getMembersFromCustomerGroupAssignedToSite<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerGroupMembersT>;
    /**
    * Action to get customer group member information.
    *
    * If you would like to get a raw Response object use the other getMemberFromCustomerGroupAssignedToSite function.
    *
    * @returns A promise of type CustomerGroupMemberT
    */
    getMemberFromCustomerGroupAssignedToSite(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CustomerGroupMemberT>;
    /**
    * Action to get customer group member information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerGroupMemberT otherwise
    */
    getMemberFromCustomerGroupAssignedToSite<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerGroupMemberT>;
    /**
    * Action to remove a customer from a static customer group.
    *
    * If you would like to get a raw Response object use the other deleteMemberFromCustomerGroupAssignedToSite function.
    *
    * @returns A promise of type void
    */
    deleteMemberFromCustomerGroupAssignedToSite(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<void>;
    /**
    * Action to remove a customer from a static customer group.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    deleteMemberFromCustomerGroupAssignedToSite<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Action to add customer to static customer group.
    *
    * If you would like to get a raw Response object use the other addMemberToCustomerGroupAssignedToSite function.
    *
    * @returns A promise of type CustomerGroupMemberT | CustomerGroupMemberT
    */
    addMemberToCustomerGroupAssignedToSite(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }): Promise<CustomerGroupMemberT | CustomerGroupMemberT>;
    /**
    * Action to add customer to static customer group.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerGroupMemberT | CustomerGroupMemberT otherwise
    */
    addMemberToCustomerGroupAssignedToSite<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
            customerGroupId: string;
            customerNo: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: object;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerGroupMemberT | CustomerGroupMemberT>;
    /**
    * Searches for customer groups.

The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:

id - String
description - String
type - String Enum value[system, dynamic, static]


The output of the query can also be sorted. These are the list of sortable attributes:

id - String
description - String
    *
    * If you would like to get a raw Response object use the other searchCustomerGroupInSite function.
    *
    * @returns A promise of type CustomerGroupSearchResultT
    */
    searchCustomerGroupInSite(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }): Promise<CustomerGroupSearchResultT>;
    /**
    * Searches for customer groups.

The query attribute specifies a complex query that can be used to narrow down the search. These are the list
of searchable attributes:

id - String
description - String
type - String Enum value[system, dynamic, static]


The output of the query can also be sorted. These are the list of sortable attributes:

id - String
description - String
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CustomerGroupSearchResultT otherwise
    */
    searchCustomerGroupInSite<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : CustomerGroupSearchResultT>;
}
declare module Customers {
    type CustomerAddress = CustomerAddressT;
    type CustomerGroupSearchResult = CustomerGroupSearchResultT;
    type CustomerList = CustomerListT;
    type CustomerSearchHit = CustomerSearchHitT;
    type CustomerGroupMembers = CustomerGroupMembersT;
    type Rule = RuleT;
    type CustomerGroup = CustomerGroupT;
    type CustomerGroupMemberSearchResult = CustomerGroupMemberSearchResultT;
    type CustomerAddressResult = CustomerAddressResultT;
    type Customer = CustomerT;
    type CustomerGroupMember = CustomerGroupMemberT;
    type Credentials = CredentialsT;
    type CustomerSearchResult = CustomerSearchResultT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type SimpleSearchResult = SimpleSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
    type Error = ErrorT;
    type ErrorResponse = ErrorResponseT;
}
export = Customers;
