import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { CampaignSearchResultT, CampaignT, ErrorResponseT, MoneyT, SimpleSearchResultT, SearchRequestT, PaginatedSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT } from "./campaigns.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class Campaigns extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Searches for campaigns using a search request object that allows filtering on various attributes.

  ## Supported Query Attributes

  The query attribute specifies a complex query that can be used to narrow down the search. A subset of these can optionally be used to sort the returned results.

  | Attribute | Type | Sortable |
  |-----------|--------|----------|
  | campaign_id | String | yes |
  | description | String | yes |
  | enabled | Boolean | yes |
  | coupon_id | String | no |
  | customer_group | String | no |
  | source_code | String | no |
  | start_date | Date | no |
  | end_date | Date | no |
  | last_modified | Date | no |

  These fields can only be used in queries as conjunctions (using &#x60;AND&#x60;). If the field is used in a disjunction (&#x60;OR&#x60;), an exception is thrown.

  ## Supported Expands

  This API does not support any expands.
    *
    * If you would like to get a raw Response object use the other campaignsSearch function.
    *
    * @returns A promise of type CampaignSearchResultT
    */
    campaignsSearch(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }): Promise<CampaignSearchResultT>;
    /**
    * Searches for campaigns using a search request object that allows filtering on various attributes.

  ## Supported Query Attributes

  The query attribute specifies a complex query that can be used to narrow down the search. A subset of these can optionally be used to sort the returned results.

  | Attribute | Type | Sortable |
  |-----------|--------|----------|
  | campaign_id | String | yes |
  | description | String | yes |
  | enabled | Boolean | yes |
  | coupon_id | String | no |
  | customer_group | String | no |
  | source_code | String | no |
  | start_date | Date | no |
  | end_date | Date | no |
  | last_modified | Date | no |

  These fields can only be used in queries as conjunctions (using &#x60;AND&#x60;). If the field is used in a disjunction (&#x60;OR&#x60;), an exception is thrown.

  ## Supported Expands

  This API does not support any expands.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CampaignSearchResultT otherwise
    */
    campaignsSearch<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : CampaignSearchResultT>;
    /**
    * Deletes the campaign by ID.
    *
    * If you would like to get a raw Response object use the other deleteCampaign function.
    *
    * @returns A promise of type void
    */
    deleteCampaign(options?: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<void>;
    /**
    * Deletes the campaign by ID.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    deleteCampaign<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Action to get campaign information.
    *
    * If you would like to get a raw Response object use the other getCampaign function.
    *
    * @returns A promise of type CampaignT
    */
    getCampaign(options?: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CampaignT>;
    /**
    * Action to get campaign information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CampaignT otherwise
    */
    getCampaign<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CampaignT>;
    /**
    * Updates the campaign with the specified information.
    *
    * If you would like to get a raw Response object use the other updateCampaign function.
    *
    * @returns A promise of type CampaignT
    */
    updateCampaign(options: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CampaignT;
    }): Promise<CampaignT>;
    /**
    * Updates the campaign with the specified information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CampaignT otherwise
    */
    updateCampaign<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CampaignT;
    }, rawResponse?: T): Promise<T extends true ? Response : CampaignT>;
    /**
    * Creates a campaign using the information provided.
    *
    * If you would like to get a raw Response object use the other createCampaign function.
    *
    * @returns A promise of type CampaignT
    */
    createCampaign(options: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CampaignT;
    }): Promise<CampaignT>;
    /**
    * Creates a campaign using the information provided.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CampaignT otherwise
    */
    createCampaign<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: CampaignT;
    }, rawResponse?: T): Promise<T extends true ? Response : CampaignT>;
}
declare module Campaigns {
    type CampaignSearchResult = CampaignSearchResultT;
    type Campaign = CampaignT;
    type ErrorResponse = ErrorResponseT;
    type Money = MoneyT;
    type SimpleSearchResult = SimpleSearchResultT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
}
export = Campaigns;
