import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { PromotionSearchResultT, TimeOfDayT, CampaignT, PromotionCampaignAssignmentT, TagT, PromotionT, PromotionAssignmentInformationT, ScheduleT, RecurrenceT, PromotionAbtestGroupAssignmentT, MoneyT, SimpleSearchResultT, SearchRequestT, PaginatedSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT, ErrorResponseT } from "./promotions.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class Promotions extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Searches for promotions.
 
 The SearchRequest document contains a search object that allows filtering on various attributes.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable
 attributes:
 
 id - String
 name - String
 currency_code - String
 exclusivity - String
 enabled - Boolean
 
 Note that only searchable attributes can be used in sorting. Additionally, the following attribute can be used to
 sort:
 
 promotion_class - String
 
    *
    * If you would like to get a raw Response object use the other promotionsSearch function.
    *
    * @returns A promise of type PromotionSearchResultT
    */
    promotionsSearch(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }): Promise<PromotionSearchResultT>;
    /**
    * Searches for promotions.
 
 The SearchRequest document contains a search object that allows filtering on various attributes.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the searchable
 attributes:
 
 id - String
 name - String
 currency_code - String
 exclusivity - String
 enabled - Boolean
 
 Note that only searchable attributes can be used in sorting. Additionally, the following attribute can be used to
 sort:
 
 promotion_class - String
 
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type PromotionSearchResultT otherwise
    */
    promotionsSearch<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : PromotionSearchResultT>;
    /**
    * Deletes the promotion by ID.
    *
    * If you would like to get a raw Response object use the other deletePromotion function.
    *
    * @returns A promise of type void
    */
    deletePromotion(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<void>;
    /**
    * Deletes the promotion by ID.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    deletePromotion<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Action to get promotion information.
    *
    * If you would like to get a raw Response object use the other getPromotion function.
    *
    * @returns A promise of type PromotionT
    */
    getPromotion(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<PromotionT>;
    /**
    * Action to get promotion information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type PromotionT otherwise
    */
    getPromotion<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : PromotionT>;
    /**
    * Updates the promotion with the specified information.
    *
    * If you would like to get a raw Response object use the other updatePromotion function.
    *
    * @returns A promise of type PromotionT
    */
    updatePromotion(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: PromotionT;
    }): Promise<PromotionT>;
    /**
    * Updates the promotion with the specified information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type PromotionT otherwise
    */
    updatePromotion<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: PromotionT;
    }, rawResponse?: T): Promise<T extends true ? Response : PromotionT>;
    /**
    * Creates a promotion using the information provided.
    *
    * If you would like to get a raw Response object use the other createPromotion function.
    *
    * @returns A promise of type PromotionT
    */
    createPromotion(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: PromotionT;
    }): Promise<PromotionT>;
    /**
    * Creates a promotion using the information provided.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type PromotionT otherwise
    */
    createPromotion<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: PromotionT;
    }, rawResponse?: T): Promise<T extends true ? Response : PromotionT>;
}
declare module Promotions {
    type PromotionSearchResult = PromotionSearchResultT;
    type TimeOfDay = TimeOfDayT;
    type Campaign = CampaignT;
    type PromotionCampaignAssignment = PromotionCampaignAssignmentT;
    type Tag = TagT;
    type Promotion = PromotionT;
    type PromotionAssignmentInformation = PromotionAssignmentInformationT;
    type Schedule = ScheduleT;
    type Recurrence = RecurrenceT;
    type PromotionAbtestGroupAssignment = PromotionAbtestGroupAssignmentT;
    type Money = MoneyT;
    type SimpleSearchResult = SimpleSearchResultT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
    type ErrorResponse = ErrorResponseT;
}
export = Promotions;
