import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { GiftCertificateT, GiftCertificateRequestT, ErrorResponseT, SearchRequestT, PaginatedSearchResultT, SimpleSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, ResultPageT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT } from "./shopperGiftCertificates.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class ShopperGiftCertificates extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Action to retrieve an existing gift certificate.
    *
    * If you would like to get a raw Response object use the other getGiftCertificate function.
    *
    * @returns A promise of type GiftCertificateT
    */
    getGiftCertificate(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: GiftCertificateRequestT;
    }): Promise<GiftCertificateT>;
    /**
    * Action to retrieve an existing gift certificate.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type GiftCertificateT otherwise
    */
    getGiftCertificate<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: GiftCertificateRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : GiftCertificateT>;
}
declare module ShopperGiftCertificates {
    type GiftCertificate = GiftCertificateT;
    type GiftCertificateRequest = GiftCertificateRequestT;
    type ErrorResponse = ErrorResponseT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type SimpleSearchResult = SimpleSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type ResultPage = ResultPageT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
}
export = ShopperGiftCertificates;
