import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { PromotionT, PromotionResultT, ErrorResponseT, SearchRequestT, PaginatedSearchResultT, SimpleSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT, ErrorT } from "./shopperPromotions.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class ShopperPromotions extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Returns an array of enabled promotions for a list of specified IDs. In the request URL, you can specify up to 50 IDs. If you specify an ID that contains either parentheses or the separator characters, you must URL encode these characters. Each request returns only enabled promotions as the server does not consider promotion qualifiers or schedules.
    *
    * If you would like to get a raw Response object use the other getPromotions function.
    *
    * @returns A promise of type PromotionResultT
    */
    getPromotions(options?: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
            ids: string;
            locale?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<PromotionResultT>;
    /**
    * Returns an array of enabled promotions for a list of specified IDs. In the request URL, you can specify up to 50 IDs. If you specify an ID that contains either parentheses or the separator characters, you must URL encode these characters. Each request returns only enabled promotions as the server does not consider promotion qualifiers or schedules.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type PromotionResultT otherwise
    */
    getPromotions<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
            ids: string;
            locale?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : PromotionResultT>;
    /**
    * Handles get promotion by filter criteria. Returns an array of enabled promotions matching the specified filter
criteria. In the request URL, you must provide a campaign_id parameter, and you can optionally specify a date
range by providing start_date and end_date parameters. Both parameters are required to specify a date range, as
omitting one causes the server to return a MissingParameterException fault. Each request returns only enabled
promotions, since the server does not consider promotion qualifiers or schedules.
    *
    * If you would like to get a raw Response object use the other getPromotionsForCampaign function.
    *
    * @returns A promise of type PromotionResultT
    */
    getPromotionsForCampaign(options?: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
            siteId?: string;
            startDate?: string;
            endDate?: string;
            currency?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<PromotionResultT>;
    /**
    * Handles get promotion by filter criteria. Returns an array of enabled promotions matching the specified filter
criteria. In the request URL, you must provide a campaign_id parameter, and you can optionally specify a date
range by providing start_date and end_date parameters. Both parameters are required to specify a date range, as
omitting one causes the server to return a MissingParameterException fault. Each request returns only enabled
promotions, since the server does not consider promotion qualifiers or schedules.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type PromotionResultT otherwise
    */
    getPromotionsForCampaign<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            campaignId: string;
            siteId?: string;
            startDate?: string;
            endDate?: string;
            currency?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : PromotionResultT>;
}
declare module ShopperPromotions {
    type Promotion = PromotionT;
    type PromotionResult = PromotionResultT;
    type ErrorResponse = ErrorResponseT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type SimpleSearchResult = SimpleSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
    type Error = ErrorT;
}
export = ShopperPromotions;
