import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { SourceCodeGroupT, SourceCodeGroupSearchResultT, SourceCodeRedirectInfoT, SourceCodeSpecificationT, ErrorResponseT, MoneyT, SimpleSearchResultT, SearchRequestT, PaginatedSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT } from "./sourceCodeGroups.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class SourceCodeGroups extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Deletes the source code group by ID.
    *
    * If you would like to get a raw Response object use the other deleteSourceCodeGroup function.
    *
    * @returns A promise of type void
    */
    deleteSourceCodeGroup(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<void>;
    /**
    * Deletes the source code group by ID.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type void otherwise
    */
    deleteSourceCodeGroup<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : void>;
    /**
    * Action to retrieve source code group information.
    *
    * If you would like to get a raw Response object use the other getSourceCodeGroup function.
    *
    * @returns A promise of type SourceCodeGroupT
    */
    getSourceCodeGroup(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            expand?: Array<string>;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<SourceCodeGroupT>;
    /**
    * Action to retrieve source code group information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroupT otherwise
    */
    getSourceCodeGroup<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            expand?: Array<string>;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : SourceCodeGroupT>;
    /**
    * Updates the source code group with the specified information.
    *
    * If you would like to get a raw Response object use the other updateSourceCodeGroup function.
    *
    * @returns A promise of type SourceCodeGroupT
    */
    updateSourceCodeGroup(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroupT;
    }): Promise<SourceCodeGroupT>;
    /**
    * Updates the source code group with the specified information.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroupT otherwise
    */
    updateSourceCodeGroup<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroupT;
    }, rawResponse?: T): Promise<T extends true ? Response : SourceCodeGroupT>;
    /**
    * Creates a source code group using the information provided.
    *
    * If you would like to get a raw Response object use the other createSourceCodeGroup function.
    *
    * @returns A promise of type SourceCodeGroupT
    */
    createSourceCodeGroup(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroupT;
    }): Promise<SourceCodeGroupT>;
    /**
    * Creates a source code group using the information provided.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroupT otherwise
    */
    createSourceCodeGroup<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SourceCodeGroupT;
    }, rawResponse?: T): Promise<T extends true ? Response : SourceCodeGroupT>;
    /**
    * Searches for source code groups.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the list
 of searchable attributes:
 
 id - String
 description - String
 source_code* - String
 start_time - DateTime
 end_time - DateTime
 creation_date - DateTime
 enabled - Boolean
 active* - Boolean
 

 * - These fields can only be used in Queries as conjunctions (using AND).  If the field is used in a disjunction
 (OR) an exception will be thrown.
 
 The output of the query can also be sorted. These are the list of sortable attributes:
 
 id - String
 description - String
 enabled - Boolean
 creation_date - DateTime
 
 
 Expands that can be applied for the search request
 
 specifications - String
 
    *
    * If you would like to get a raw Response object use the other sourceCodeGroupsSearch function.
    *
    * @returns A promise of type SourceCodeGroupSearchResultT
    */
    sourceCodeGroupsSearch(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }): Promise<SourceCodeGroupSearchResultT>;
    /**
    * Searches for source code groups.
 
 The query attribute specifies a complex query that can be used to narrow down the search. These are the list
 of searchable attributes:
 
 id - String
 description - String
 source_code* - String
 start_time - DateTime
 end_time - DateTime
 creation_date - DateTime
 enabled - Boolean
 active* - Boolean
 

 * - These fields can only be used in Queries as conjunctions (using AND).  If the field is used in a disjunction
 (OR) an exception will be thrown.
 
 The output of the query can also be sorted. These are the list of sortable attributes:
 
 id - String
 description - String
 enabled - Boolean
 creation_date - DateTime
 
 
 Expands that can be applied for the search request
 
 specifications - String
 
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SourceCodeGroupSearchResultT otherwise
    */
    sourceCodeGroupsSearch<T extends boolean>(options: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
        body: SearchRequestT;
    }, rawResponse?: T): Promise<T extends true ? Response : SourceCodeGroupSearchResultT>;
}
declare module SourceCodeGroups {
    type SourceCodeGroup = SourceCodeGroupT;
    type SourceCodeGroupSearchResult = SourceCodeGroupSearchResultT;
    type SourceCodeRedirectInfo = SourceCodeRedirectInfoT;
    type SourceCodeSpecification = SourceCodeSpecificationT;
    type ErrorResponse = ErrorResponseT;
    type Money = MoneyT;
    type SimpleSearchResult = SimpleSearchResultT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
}
export = SourceCodeGroups;
