import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { OptionValueT, MasterT, CategoryT, CategoryResultT, VariationAttributeT, RecommendationTypeT, ProductTypeT, RecommendationT, VariantT, VariationGroupT, ProductResultT, ProductLinkT, InventoryT, ImageGroupT, OptionT, ProductT, ImageT, VariationAttributeValueT, ProductPromotionT, BundledProductT, SearchRequestT, PaginatedSearchResultT, SimpleSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT, ErrorResponseT } from "./shopperProducts.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class ShopperProducts extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Allows access to multiple products by a single request. Only products that are online and assigned to a site catalog are returned. The maximum number of productIDs that can be requested are 24. Alongwith product details, the availability, images, price, promotion and variations data for the valid products will be included as appropriate.
    *
    * If you would like to get a raw Response object use the other getProducts function.
    *
    * @returns A promise of type ProductResultT
    */
    getProducts(options?: {
        parameters?: {
            organizationId?: string;
            ids: string;
            inventoryIds?: string;
            currency?: string;
            locale?: string;
            allImages?: boolean;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<ProductResultT>;
    /**
    * Allows access to multiple products by a single request. Only products that are online and assigned to a site catalog are returned. The maximum number of productIDs that can be requested are 24. Alongwith product details, the availability, images, price, promotion and variations data for the valid products will be included as appropriate.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ProductResultT otherwise
    */
    getProducts<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            ids: string;
            inventoryIds?: string;
            currency?: string;
            locale?: string;
            allImages?: boolean;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : ProductResultT>;
    /**
    * Allows access to product details for a single product ID. Only products that are online and assigned to a site catalog are returned. Along with product details, the availability,images,price,bundled_products,set_products,recommedations,productoptions,variation and promotion data for the products will be included as appropriate.
    *
    * If you would like to get a raw Response object use the other getProduct function.
    *
    * @returns A promise of type ProductT
    */
    getProduct(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            inventoryIds?: string;
            currency?: string;
            locale?: string;
            allImages?: boolean;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<ProductT>;
    /**
    * Allows access to product details for a single product ID. Only products that are online and assigned to a site catalog are returned. Along with product details, the availability,images,price,bundled_products,set_products,recommedations,productoptions,variation and promotion data for the products will be included as appropriate.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ProductT otherwise
    */
    getProduct<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            inventoryIds?: string;
            currency?: string;
            locale?: string;
            allImages?: boolean;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : ProductT>;
    /**
    * When you use the URL template, the server returns multiple categories (a result object of category documents). You can use this template as a convenient way of obtaining multiple categories in a single request, instead of issuing separate requests for each category. You can specify up to 50 multiple IDs. You must enclose the list of IDs in parentheses. If a category identifier contains parenthesis or the separator sign, you must URL encode the character. The server only returns online categories.
    *
    * If you would like to get a raw Response object use the other getCategories function.
    *
    * @returns A promise of type CategoryResultT
    */
    getCategories(options?: {
        parameters?: {
            organizationId?: string;
            ids: string;
            levels?: number;
            locale?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CategoryResultT>;
    /**
    * When you use the URL template, the server returns multiple categories (a result object of category documents). You can use this template as a convenient way of obtaining multiple categories in a single request, instead of issuing separate requests for each category. You can specify up to 50 multiple IDs. You must enclose the list of IDs in parentheses. If a category identifier contains parenthesis or the separator sign, you must URL encode the character. The server only returns online categories.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CategoryResultT otherwise
    */
    getCategories<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            ids: string;
            levels?: number;
            locale?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CategoryResultT>;
    /**
    * When you use the URL template below, the server returns a category identified by its ID; by default, the server
also returns the first level of subcategories, but you can specify another level by setting the levels
parameter. The server only returns online categories.
    *
    * If you would like to get a raw Response object use the other getCategory function.
    *
    * @returns A promise of type CategoryT
    */
    getCategory(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            levels?: number;
            locale?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<CategoryT>;
    /**
    * When you use the URL template below, the server returns a category identified by its ID; by default, the server
also returns the first level of subcategories, but you can specify another level by setting the levels
parameter. The server only returns online categories.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type CategoryT otherwise
    */
    getCategory<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            levels?: number;
            locale?: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : CategoryT>;
}
declare module ShopperProducts {
    type OptionValue = OptionValueT;
    type Master = MasterT;
    type Category = CategoryT;
    type CategoryResult = CategoryResultT;
    type VariationAttribute = VariationAttributeT;
    type RecommendationType = RecommendationTypeT;
    type ProductType = ProductTypeT;
    type Recommendation = RecommendationT;
    type Variant = VariantT;
    type VariationGroup = VariationGroupT;
    type ProductResult = ProductResultT;
    type ProductLink = ProductLinkT;
    type Inventory = InventoryT;
    type ImageGroup = ImageGroupT;
    type Option = OptionT;
    type Product = ProductT;
    type Image = ImageT;
    type VariationAttributeValue = VariationAttributeValueT;
    type ProductPromotion = ProductPromotionT;
    type BundledProduct = BundledProductT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type SimpleSearchResult = SimpleSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
    type ErrorResponse = ErrorResponseT;
}
export = ShopperProducts;
