import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { ProductRefT, SuggestedTermsT, CategorySuggestionsT, SuggestedProductT, SuggestedPhraseT, VariationAttributeT, ProductSuggestionsT, SuggestedCategoryT, ProductTypeT, BrandSuggestionsT, ProductSearchRefinementValueT, ProductSearchSortingOptionT, SuggestedTermT, ProductSearchRefinementT, CustomSuggestionsT, ProductSearchHitT, ProductSearchResultT, ImageT, VariationAttributeValueT, SuggestionT, SuggestionResultT, MoneyT, SimpleSearchResultT, SearchRequestT, PaginatedSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT, ErrorResponseT } from "./shopperSearch.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class ShopperSearch extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * Provides keyword and refinement search functionality for products. Only returns the product ID, link, and name in
the product search hit. The search result contains only products that are online and assigned to site catalog.
    *
    * If you would like to get a raw Response object use the other productSearch function.
    *
    * @returns A promise of type ProductSearchResultT
    */
    productSearch(options?: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
            q?: string;
            refine?: Array<string>;
            sort?: string;
            currency?: any;
            locale?: any;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<ProductSearchResultT>;
    /**
    * Provides keyword and refinement search functionality for products. Only returns the product ID, link, and name in
the product search hit. The search result contains only products that are online and assigned to site catalog.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type ProductSearchResultT otherwise
    */
    productSearch<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
            q?: string;
            refine?: Array<string>;
            sort?: string;
            currency?: any;
            locale?: any;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : ProductSearchResultT>;
    /**
    * Provides keyword search functionality for products, categories, and brands suggestions. Returns suggested products, suggested categories, and suggested brands for the given search phrase.
    *
    * If you would like to get a raw Response object use the other getSearchSuggestions function.
    *
    * @returns A promise of type SuggestionResultT
    */
    getSearchSuggestions(options?: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
            q: string;
            limit?: number;
            currency?: any;
            locale?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<SuggestionResultT>;
    /**
    * Provides keyword search functionality for products, categories, and brands suggestions. Returns suggested products, suggested categories, and suggested brands for the given search phrase.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type SuggestionResultT otherwise
    */
    getSearchSuggestions<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
            q: string;
            limit?: number;
            currency?: any;
            locale?: any;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : SuggestionResultT>;
}
declare module ShopperSearch {
    type ProductRef = ProductRefT;
    type SuggestedTerms = SuggestedTermsT;
    type CategorySuggestions = CategorySuggestionsT;
    type SuggestedProduct = SuggestedProductT;
    type SuggestedPhrase = SuggestedPhraseT;
    type VariationAttribute = VariationAttributeT;
    type ProductSuggestions = ProductSuggestionsT;
    type SuggestedCategory = SuggestedCategoryT;
    type ProductType = ProductTypeT;
    type BrandSuggestions = BrandSuggestionsT;
    type ProductSearchRefinementValue = ProductSearchRefinementValueT;
    type ProductSearchSortingOption = ProductSearchSortingOptionT;
    type SuggestedTerm = SuggestedTermT;
    type ProductSearchRefinement = ProductSearchRefinementT;
    type CustomSuggestions = CustomSuggestionsT;
    type ProductSearchHit = ProductSearchHitT;
    type ProductSearchResult = ProductSearchResultT;
    type Image = ImageT;
    type VariationAttributeValue = VariationAttributeValueT;
    type Suggestion = SuggestionT;
    type SuggestionResult = SuggestionResultT;
    type Money = MoneyT;
    type SimpleSearchResult = SimpleSearchResultT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
    type ErrorResponse = ErrorResponseT;
}
export = ShopperSearch;
