import { BaseClient, ClientConfig, Response } from "@commerce-apps/core";
import { ErrorResponseT, MoneyT, SimpleSearchResultT, SearchRequestT, PaginatedSearchResultT, BoolFilterT, MatchAllQueryT, FilteredQueryT, QueryFilterT, QueryT, TermQueryT, TermFilterT, TextQueryT, Range2FilterT, BoolQueryT, NestedQueryT, FilterT, SortT, RangeFilterT, StoreResultT, StoreT } from "./shopperStores.types";
/**
* Instantiate a Client object with desired ClientConfig to perform operations
* available in this API client.
*
* Note: When performing operations that require ShopperJWT authentication, an
* Authorization header containing a JWT can be added to the headers field of the
* ClientConfig object. The Client will use that Authorization header for all the
* operations it is used to perform.
*/
declare class ShopperStores extends BaseClient {
    constructor(config: ClientConfig);
    /**
    * This resource retrieves a list of stores for the given site that are within a configured distance of a geolocation. The distance is interpreted either in miles or kilometers, depending on the distanceUnit input parameter. The location is specified either by directly providing a latitude and longitude coordinate pair, or by providing a country and a postal code. If a postal code is passed, the resource looks in the system&#x27;s geolocation mappings to find the coordinates for this postal code. If no matching geolocation is found, the resource returns an empty list of stores. If coordinates are passed, the values for country and postal code are ignored.
    *
    * If you would like to get a raw Response object use the other getStores function.
    *
    * @returns A promise of type StoreResultT
    */
    getStores(options?: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
            latitude?: number;
            longitude?: number;
            countryCode?: string;
            postalCode?: string;
            distanceUnit?: string;
            maxDistance?: number;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<StoreResultT>;
    /**
    * This resource retrieves a list of stores for the given site that are within a configured distance of a geolocation. The distance is interpreted either in miles or kilometers, depending on the distanceUnit input parameter. The location is specified either by directly providing a latitude and longitude coordinate pair, or by providing a country and a postal code. If a postal code is passed, the resource looks in the system&#x27;s geolocation mappings to find the coordinates for this postal code. If no matching geolocation is found, the resource returns an empty list of stores. If coordinates are passed, the values for country and postal code are ignored.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type StoreResultT otherwise
    */
    getStores<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            siteId?: string;
            latitude?: number;
            longitude?: number;
            countryCode?: string;
            postalCode?: string;
            distanceUnit?: string;
            maxDistance?: number;
            offset?: number;
            limit?: number;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : StoreResultT>;
    /**
    * Returns a store identified by its ID.
    *
    * If you would like to get a raw Response object use the other getStore function.
    *
    * @returns A promise of type StoreT
    */
    getStore(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }): Promise<StoreT>;
    /**
    * Returns a store identified by its ID.
    *
    * @returns A promise of type Response if rawResponse is true, a promise of type StoreT otherwise
    */
    getStore<T extends boolean>(options?: {
        parameters?: {
            organizationId?: string;
            id: string;
            siteId?: string;
        };
        headers?: {
            [key: string]: string;
        };
    }, rawResponse?: T): Promise<T extends true ? Response : StoreT>;
}
declare module ShopperStores {
    type ErrorResponse = ErrorResponseT;
    type Money = MoneyT;
    type SimpleSearchResult = SimpleSearchResultT;
    type SearchRequest = SearchRequestT;
    type PaginatedSearchResult = PaginatedSearchResultT;
    type BoolFilter = BoolFilterT;
    type MatchAllQuery = MatchAllQueryT;
    type FilteredQuery = FilteredQueryT;
    type QueryFilter = QueryFilterT;
    type Query = QueryT;
    type TermQuery = TermQueryT;
    type TermFilter = TermFilterT;
    type TextQuery = TextQueryT;
    type Range2Filter = Range2FilterT;
    type BoolQuery = BoolQueryT;
    type NestedQuery = NestedQueryT;
    type Filter = FilterT;
    type Sort = SortT;
    type RangeFilter = RangeFilterT;
    type StoreResult = StoreResultT;
    type Store = StoreT;
}
export = ShopperStores;
